================
climlab Courseware
================
----------
 Teaching climate science through hands-on climate modeling
----------

Author
=============
| **Brian E. J. Rose**
| Department of Atmospheric and Environmental Sciences
| University at Albany
| brose@albany.edu

About
----------------

This is a collection of ``Jupyter`` notebooks (aka ``IPython``) used for teaching
some basics of climate science, and documenting use of the 
``climlab`` Python package.

These should all run out-of-the-box once ``climlab`` is installed, e.g:

``jupyter notebook Insolation.ipynb``

will open the notebook in a browser.

